<?php

namespace Drupal\contact_emails;

use Drupal\Core\Mail\MailManager;
use Drupal\Core\Utility\Token;
use Drupal\contact_emails\ContactEmails;

/**
 * Class ContactEmailerService.
 *
 * @package Drupal\contact_emails
 */
class ContactEmailerService {

  /**
   * Drupal\Core\Mail\MailManager definition.
   *
   * @var \Drupal\Core\Mail\MailManager
   */
  protected $mailManager;

  /**
   * Drupal\Core\Utility\Token definition.
   *
   * @var \Drupal\Core\Utility\Token
   */
  protected $token;

  /**
   * Contact form machine name.
   *
   * @var string
   */
  protected $contactForm;

  /**
   * Contact message entity.
   *
   * @var object
   */
  protected $contactMessage;

  /**
   * Constructor.
   */
  public function __construct(MailManager $plugin_manager_mail, Token $token) {
    $this->mailManager = $plugin_manager_mail;
    $this->token = $token;
  }

  /**
   * Set the contact form.
   *
   * @param object $contactMessage
   *   The contact message.
   */
  public function setContactMessage($contactMessage) {
    $contactForm_object = $contactMessage->getContactForm();
    $this->contactForm = $contactForm_object->id();
    $this->contactMessage = $contactMessage;
  }

  /**
   * Send the emails.
   */
  public function sendEmails() {
    if ($emails = $this->getEmails()) {
      foreach ($emails as $email) {
        $module = 'contact_emails';
        $key = 'contact_emails';

        // Recipients.
        if ($email->recipient_is_submitter) {
          $to = $this->contactMessage->getSenderMail();
        }
        else {
          $to = implode(', ', $email->recipients);
        }

        // Subject and body.
        $params['subject'] = $email->subject;
        $params['message'] = $email->body;
        $this->token->replace($params['message'], [
          'contactMessage' => $this->contactMessage,
        ]);

        // Final prep and send.
        $langcode = \Drupal::currentUser()->getPreferredLangcode();
        $send = TRUE;
        $reply = NULL;
        $result = $this->mailManager->mail($module, $key, $to, $langcode, $params, $reply, $send);
      }
    }
  }

  /**
   * Get the emails.
   */
  private function getEmails() {
    $include_disabled = FALSE;
    return ContactEmails::getEmailsByContactForm($this->contactForm, $include_disabled);
  }

}
