<?php

namespace Drupal\contact_emails\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Database\Driver\mysql\Connection;
use Drupal\Core\Url;

/**
 * Class ContactEmailDeleteForm.
 *
 * @package Drupal\contact_emails\Form
 */
class ContactEmailDeleteForm extends ConfirmFormBase {

  /**
   * Drupal\Core\Database\Driver\mysql\Connection definition.
   *
   * @var \Drupal\Core\Database\Driver\mysql\Connection
   */
  protected $database;

  /**
   * Machine name of contact form.
   *
   * @var string
   */
  protected $contactForm;

  /**
   * {@inheritdoc}
   */
  public function __construct(Connection $database) {
    $this->database = $database;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'contact_email_delete_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getFormName() {
    return 'confirm';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return t('Do you want to delete this email?');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return t('Proceding will permanently delete this email.');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return t('Delete');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelText() {
    return t('Cancel');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('contact_emails.contact_emails_controller_list', [
      'contactForm' => $this->contactForm,
    ]);
  }

  /**
   * {@inheritdoc}
   *
   * @param int $id
   *   (optional) The ID of the item to be deleted.
   */
  public function buildForm(array $form, FormStateInterface $form_state, $contactForm = '', $id = '') {
    $this->contactForm = $contactForm;
    $this->id = $id;

    $form['id'] = [
      '#type' => 'hidden',
      '#value' => $id,
    ];
    $form['contactForm'] = [
      '#type' => 'hidden',
      '#value' => $contactForm,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();

    // Run deletion.
    $this->database->delete('contact_message_email_settings')
      ->condition('id', $values['id'])
      ->condition('contactForm', $values['contactForm'])
      ->execute();

    // Add message.
    drupal_set_message(t('The email has been successfully removed.'), 'status');

    // Redirect back to list page.
    $form_state->setRedirect('contact_emails.contact_emails_controller_list', [
      'contactForm' => $values['contactForm'],
    ]);
  }

}
